Once you have read the `RQL tutorial`_ and you know the application'`schema`_,
you're ready to define your own views. Just type the RQL query retreiving data
you're interested in in the search field. If the view used to display them
doesn't fit your need, choose another one in the possible views box (this box
isn't displayed by default, but you can activate it in your `user
preferences`_). Once you're satified, add a `bookmark`_ if you want to reuse
this view later.

.. _`RQL tutorial`: doc/tut_rql
.. _`schema`: schema
.. _`user preferences`: myprefs
.. _`bookmark`: doc/bookmarks


Below are some example of what can be acheived...

.. winclude:: custom_view_last_update
.. winclude:: custom_view_rss
